@@ -185,7 +185,23 @@ class KinesisStreamsToKinesisFirehoseToS3(
         :summary: Constructs a new instance of the KinesisStreamsToKinesisFirehoseToS3 class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(KinesisStreamsToKinesisFirehoseToS3.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+                existing_logging_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
+                kinesis_firehose_props: typing.Any = None,
+                kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
+                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+                log_s3_access_logs: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = KinesisStreamsToKinesisFirehoseToS3Props(
@@ -304,7 +320,21 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if __debug__:
-            type_hints = typing.get_type_hints(KinesisStreamsToKinesisFirehoseToS3Props.__init__)
+            def stub(
+                *,
+                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+                existing_logging_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
+                kinesis_firehose_props: typing.Any = None,
+                kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
+                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+                log_s3_access_logs: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
             check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
             check_type(argname="argument existing_bucket_obj", value=existing_bucket_obj, expected_type=type_hints["existing_bucket_obj"])
